==> alfresco-repository-23.7.0.8-sources.jar: org/alfresco/util/json/AbstractJsonSerializerBean.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.util.json;

/**
 * @author Nick Smith
 */
public abstract class AbstractJsonSerializerBean<T, S> implements JsonSerializer<T, S>
{
    private Class<? extends T> classToSerialize;
    private AlfrescoJsonSerializer jsonSerializer;

    /**
     * @param classToSerialize the classToSerialize to set
     */
    public void setClassToSerialize(Class<? extends T> classToSerialize)
    {
        this.classToSerialize = classToSerialize;
    }

    /**
     * @param jsonSerializer the jsonSerializer to set
     */
    public void setJsonSerializer(AlfrescoJsonSerializer jsonSerializer)
    {
        this.jsonSerializer = jsonSerializer;
    }

    public void init()
    {
        jsonSerializer.register(classToSerialize, this);
    }

}

==> alfresco-repository-26.1.0.41-sources.jar: org/alfresco/util/json/AbstractJsonSerializerBean.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.util.json;

/**
 * @author Nick Smith
 */
public abstract class AbstractJsonSerializerBean<T, S> implements JsonSerializer<T, S>
{
    private Class<? extends T> classToSerialize;
    private AlfrescoJsonSerializer jsonSerializer;

    /**
     * @param classToSerialize
     *            the classToSerialize to set
     */
    public void setClassToSerialize(Class<? extends T> classToSerialize)
    {
        this.classToSerialize = classToSerialize;
    }

    /**
     * @param jsonSerializer
     *            the jsonSerializer to set
     */
    public void setJsonSerializer(AlfrescoJsonSerializer jsonSerializer)
    {
        this.jsonSerializer = jsonSerializer;
    }

    public void init()
    {
        jsonSerializer.register(classToSerialize, this);
    }

}
